@@ -1,3 +1,5 @@
+import os
+
 import toolcli
 
 import ctc
@@ -7,7 +9,6 @@ command_index = {
     #
     # admin commands
     (): 'ctc.cli.commands.root_command',
-    ('cd',): 'ctc.cli.commands.admin.cd_command',
     ('config',): 'ctc.cli.commands.admin.config_command',
     ('config', 'edit'): 'ctc.cli.commands.admin.config.edit_command',
     ('config', 'path'): 'ctc.cli.commands.admin.config.path_command',
@@ -43,6 +44,8 @@ command_index = {
     # protocol commands
     ('cg',): 'ctc.cli.commands.data.cg_command',
     ('chainlink',): 'ctc.protocols.chainlink_utils.cli.chainlink_command',
+    ('chainlink', 'ls'): 'ctc.protocols.chainlink_utils.cli.chainlink_ls_command',
+    ('curve', 'pools'): 'ctc.protocols.curve_utils.cli.curve_pools_command',
     ('ens',): 'ctc.protocols.ens_utils.cli.ens_command',
     ('ens', 'exists'): 'ctc.protocols.ens_utils.cli.ens.exists_command',
     ('ens', 'hash'): 'ctc.protocols.ens_utils.cli.ens.hash_command',
@@ -62,7 +65,9 @@ command_index = {
         'pcv',
         'deposits',
     ): 'ctc.protocols.fei_utils.cli.fei.pcv_deposits_command',
-    ('rari', 'fuse'): 'ctc.protocols.rari_utils.cli.rari.fuse_command',
+    ('rari',): 'ctc.protocols.rari_utils.cli.rari.fuse_command',
+    ('rari', 'pools'): 'ctc.protocols.rari_utils.cli.rari.pools_command',
+    # ('uniswap', 'chart'): 'ctc.protocols.uniswap_v2_utils.cli.chart_command',
     ('uniswap', 'mints'): 'ctc.protocols.uniswap_v2_utils.cli.mints_command',
     ('uniswap', 'burns'): 'ctc.protocols.uniswap_v2_utils.cli.burns_command',
     ('uniswap', 'swaps'): 'ctc.protocols.uniswap_v2_utils.cli.swaps_command',
@@ -79,19 +84,77 @@ command_index = {
 }
 
 
-description = 'if using ctc for the first time, run:\n    ctc setup'
+description = """ctc is a tool for historical data analysis of Ethereum and other EVM chains
+
+if using ctc for the first time, run:
+    [option]ctc setup[/option]
+
+for quick lookups of an address, block, tx, or timestamp, run:
+    [option]ctc QUERY[/option]"""
+
+
+cd_dir_help = {
+    'code': 'directory where ctc code is stored',
+    'data': 'directory where ctc stores data',
+    'default_data': 'directory where ctc stores default data',
+    'config': 'directory where ctc stores config',
+    'notebooks': 'directory where ctc stores notebooks',
+}
+
+
+def cd_dir_getter(dirname: str) -> str:
+    import ctc
+    import ctc.config
+
+    if dirname == 'code':
+        return ctc.__path__[0]
+
+    elif dirname == 'data':
+        return ctc.config.get_data_dir()
+
+    elif dirname == 'default_data':
+        return ctc.config.get_default_data_dir()
+
+    elif dirname == 'config':
+        return os.path.dirname(ctc.config.get_config_path())
+
+    elif dirname == 'notebooks':
+        return ctc.config.get_reports_dir()
+
+    else:
+        raise Exception('unknown directory: ' + str(dirname))
 
 
 def run_cli(raw_command=None, **toolcli_kwargs):
 
     config = {
-        'include_cd': True,
-        'include_debug': True,
+        #
+        # metadata
+        'base_command': 'ctc',
+        'description': description,
+        'version': ctc.__version__,
+        'cd_dir_help': cd_dir_help,
+        'cd_dir_getter': cd_dir_getter,
+        #
+        'style_theme': {
+            'title': 'bold #ce93f9',
+            # 'description': '#f1fa8c',
+            # 'metavar': '#8be9fd',
+            'description': '#b9f29f',
+            'option': '#64aaaa',
+            # 'description': '#64aaaa',
+            'comment': '#6272a4',
+            # 'comment': '#8be9fd',
+        },
+        #
+        # subcommands
+        'include_cd_subcommand': True,
         'include_version_subcommand': True,
         'include_help_subcommand': True,
-        'version': ctc.__version__,
-        'description': description,
-        'base_command': 'ctc',
+        'include_cli_subcommand': True,
+        #
+        # args
+        'include_debug_arg': True,
     }
     toolcli_kwargs = dict({'config': config}, **toolcli_kwargs)
 
