@@ -9,15 +9,27 @@ def get_command_spec():
         'f': async_address_command,
         'help': 'summarize address',
         'args': [
-            {'name': 'address'},
-            {'name': ['-v', '--verbose'], 'action': 'store_true'},
-            {'name': '--network'},
+            {'name': 'address', 'help': 'address to get summary of'},
+            {
+                'name': ['-v', '--verbose'],
+                'action': 'store_true',
+                'help': 'emit extra output',
+            },
+            {
+                'name': '--network',
+                'metavar': 'NAME_OR_ID',
+                'help': 'network name or id to scan address of',
+            },
         ],
     }
 
 
 async def async_address_command(address, verbose, network, **kwargs):
-    max_width = os.get_terminal_size().columns
+    try:
+        max_width = os.get_terminal_size().columns
+    except OSError:
+        max_width = 80
+
     if verbose:
         verbose = 2
     await evm.async_print_address_summary(
