@@ -1,6 +1,10 @@
+from __future__ import annotations
+
+import typing
+
 import numpy as np
 import pandas as pd
-
+import toolcli
 import tooltime
 
 from ctc import evm
@@ -10,27 +14,39 @@ from ctc import spec
 from ctc.cli import cli_utils
 
 
-def get_command_spec():
+def get_command_spec() -> toolcli.CommandSpec:
     return {
         'f': async_block_command,
         'help': 'output information about blocks',
         'args': [
-            {'name': 'blocks', 'nargs': '+'},
-            {'name': '--attributes', 'nargs': '+'},
-            {'name': '--output', 'default': 'stdout'},
-            {'name': '--overwrite', 'action': 'store_true'},
-            {'name': '--provider'},
+            {'name': 'blocks', 'nargs': '+', 'help': 'block range to fetch'},
+            {
+                'name': '--attributes',
+                'nargs': '+',
+                'help': 'attributes to fetch from each block',
+            },
+            {
+                'name': '--output',
+                'default': 'stdout',
+                'help': 'file path for output (.json or .csv)',
+            },
+            {
+                'name': '--overwrite',
+                'action': 'store_true',
+                'help': 'specify that output path can be overwritten',
+            },
+            {'name': '--provider', 'help': 'rpc provider to use'},
         ],
     }
 
 
 async def async_block_command(
-    attributes,
-    blocks,
-    output,
-    provider,
-    overwrite,
-):
+    blocks: typing.Sequence[str],
+    attributes: typing.Optional[typing.Sequence[str]],
+    output: typing.Optional[typing.Sequence[str]],
+    overwrite: typing.Optional[bool],
+    provider: typing.Optional[typing.Sequence[str]],
+) -> None:
 
     if attributes is None:
         # gas stats as well
@@ -51,7 +67,7 @@ async def async_block_command(
         ]
 
     # determine blocks
-    export_blocks = await cli_utils.async_resolve_blocks(blocks)
+    export_blocks = await cli_utils.async_resolve_block_range(blocks)
 
     # print summary
     print('exporting from', len(export_blocks), 'blocks')
@@ -81,8 +97,7 @@ async def async_block_command(
     # special attribute: gas stats
     if compute_gas:
         gas_stats = pd.DataFrame(
-            evm.get_block_gas_stats(block_data)
-            for block_data in blocks_data
+            evm.get_block_gas_stats(block_data) for block_data in blocks_data
         )
         for gas_attr in gas_attrs:
             if gas_attr in attributes:
@@ -105,7 +120,7 @@ async def async_block_command(
     # output data
     if 'number' in df:
         df = df.set_index('number')
-    cli_utils.output_data(df=df, output=output, overwrite=overwrite)
+    cli_utils.output_data(df, output=output, overwrite=overwrite)
 
     # cleanup
     await rpc.async_close_http_session()
