@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import toolstr
 
 from ctc import evm
@@ -9,10 +11,14 @@ def get_command_spec():
         'f': async_balance_command,
         'help': 'output an ERC20 balance',
         'args': [
-            {'name': 'erc20_address'},
-            {'name': 'wallet_address'},
-            {'name': '--block'},
-            {'name': '--raw', 'action': 'store_true'},
+            {'name': 'erc20_address', 'help': 'address of ERC20 token'},
+            {'name': 'wallet_address', 'help': 'address of wallet'},
+            {'name': '--block', 'help': 'block number'},
+            {
+                'name': '--raw',
+                'action': 'store_true',
+                'help': 'whether to normalize balance by ERC20 decimals',
+            },
         ],
     }
 
