@@ -17,6 +17,7 @@ async def async_get_full_feed_event_data(
     interpolate: bool = False,
     provider: spec.ProviderSpec = None,
     keep_multiindex: bool = False,
+    invert: bool = False,
 ) -> spec.DataFrame:
     """
     TODO: be able to gather data across multiple aggregator changes
@@ -64,8 +65,12 @@ async def async_get_full_feed_event_data(
     # interpolate
     if interpolate:
 
+        if keep_multiindex:
+            raise Exception('cannot use keep_multiindex and interpolate')
+        df.index = pd_utils.keep_level(df.index, level='block_number')
+
         # add initial data
-        if start_block < df.index.values[0][0]:
+        if start_block < df.index.values[0]:
             import pandas as pd
 
             initial_data = await feed_datum.async_get_feed_datum(
@@ -75,7 +80,6 @@ async def async_get_full_feed_event_data(
                 normalize=normalize,
                 fields='full',
             )
-            df.index = pd_utils.keep_level(df.index, level='block_number')
             initial_df = pd.DataFrame(initial_data, index=[start_block])
             df = pd.concat([initial_df, df])
 
@@ -87,6 +91,9 @@ async def async_get_full_feed_event_data(
     elif not keep_multiindex:
         df.index = pd_utils.keep_level(df.index, level='block_number')
 
+    if invert:
+        df['answer'] = 1 / df['answer']
+
     return df
 
 
@@ -98,6 +105,7 @@ async def async_get_answer_feed_event_data(
     interpolate: bool = False,
     provider: spec.ProviderSpec = None,
     keep_multiindex: bool = False,
+    invert: bool = False,
 ) -> spec.Series:
 
     df = await async_get_full_feed_event_data(
@@ -108,6 +116,7 @@ async def async_get_answer_feed_event_data(
         interpolate=interpolate,
         provider=provider,
         keep_multiindex=keep_multiindex,
+        invert=invert,
     )
 
     return df['answer']
