@@ -1,32 +1,35 @@
 import asyncio
 
+import toolcli
 import toolstr
-import tooltable
+import tooltable  # type: ignore
 
 from ctc import evm
 from ctc import rpc
+from ctc import spec
 from ctc.protocols import fei_utils
 
 
-def get_command_spec():
+def get_command_spec() -> toolcli.CommandSpec:
     return {
         'f': async_pcv_assets_command,
         'help': 'output summary of Fei PCV assets',
         'args': [
-            {'name': '--block'},
+            {'name': '--block', 'help': 'block number'},
         ],
     }
 
 
-async def async_pcv_assets_command(block):
+async def async_pcv_assets_command(block: str) -> None:
     await async_print_pcv_assets(block=block)
     await rpc.async_close_http_session()
 
 
-async def async_print_pcv_assets(block):
+async def async_print_pcv_assets(block: spec.BlockNumberReference) -> None:
 
     if block is not None:
-        block = int(block)
+        if isinstance(block, str) and block.isnumeric():
+            block = int(block)
 
     tokens_deposits = await fei_utils.async_get_tokens_deposits(block=block)
 
