@@ -1,25 +1,30 @@
+from __future__ import annotations
+
+import toolcli
 import toolstr
+import typing
 
 from ctc import evm
 from ctc import directory
 from ctc import rpc
+from ctc import spec
 from ctc.protocols import fei_utils
 
 
-def get_command_spec():
+def get_command_spec() -> toolcli.CommandSpec:
     return {
         'f': async_pcv_command,
         'help': 'output summary of Fei PCV',
         'args': [
-            {'name': '--block'},
+            {'name': '--block', 'help': 'block number'},
         ],
     }
 
 
-async def async_pcv_command(block):
+async def async_pcv_command(block: typing.Optional[spec.BlockNumberReference]) -> None:
 
     if block is not None:
-        block = int(block)
+        block = await evm.async_block_number_to_int(block)
 
     pcv_stats = await fei_utils.async_get_pcv_stats(block=block)
     FEI = directory.get_erc20_address('FEI')
@@ -44,7 +49,7 @@ async def async_pcv_command(block):
         print('- PCV equity:', toolstr.format(protocol_equity, **format_kwargs))
         print('- CR:', toolstr.format(cr, percentage=True))
     elif output == 'table':
-        import tooltable
+        import tooltable  # type: ignore
 
         rows = [
             ['total PCV', toolstr.format(total_pcv, **format_kwargs)],
