@@ -7,12 +7,20 @@ from ctc import rpc
 def get_command_spec():
     return {
         'f': async_swaps_command,
-        'help': 'output information about pool mints',
+        'help': 'output information about pool swaps',
         'args': [
-            {'name': 'pool'},
-            {'name': '--blocks', 'nargs': '+'},
-            {'name': '--output'},
-            {'name': '--overwrite', 'action': 'store_true'},
+            {'name': 'pool', 'help': 'pool address'},
+            {'name': '--blocks', 'nargs': '+', 'help': 'block number range'},
+            {
+                'name': '--output',
+                'default': 'stdout',
+                'help': 'file path for output (.json or .csv)',
+            },
+            {
+                'name': '--overwrite',
+                'action': 'store_true',
+                'help': 'specify that output path can be overwritten',
+            },
         ],
     }
 
